@@ -3,6 +3,9 @@
 #Could make bounce effect when hit boundaries by sending in opposite direction for count down moment
 #could make accelrate faster by using previuos x,y as well as start x,y as startx,y means you cant accelerate until back to starting point.
 
+#               Much simplified the controls getting rid of step acceleration in favour of direct link to acceleromoter
+#               Don't map me straight away to avoid crash at start of immortal tail
+#20.05.10   Recalibrate after each death/meal
 #               Display a circle around the food as its hard to see in new background = animate
 #               Delete toy with real background
 #               Become immortal again one collect toy
@@ -53,8 +56,8 @@ unit_speed=.25
 speed=.5          #Speed can be float and move will occur in integers
 level_speed = speed
 smooth=10       #Rate of change in accelerometer before a speed/direction change is registered
-accel_div=12
-max_accel=2
+accel_div=12    #12 divisions is about right. 24 will give more accurate control for beginners but slower
+max_accel=5
 map_accel = 1
 accel_x=0
 accel_y=0
@@ -71,6 +74,7 @@ food_char="F"
 toy_char = "T"
 bumper_size = 8  #No of pixals around outside  of snapy where can't crash
 immortal_period = 20
+accel_tipping_point = 700
 
 
 #Globals
@@ -80,6 +84,8 @@ az = 0
 old_ax=0
 old_ay=0
 old_az=0
+calc_accel_y =0
+calc_accel_x = 0
 vibx, viby=0, 0
 cx, cy, cz = 0, 0, 0
 x, y, z =  screen_x / 2, screen_y /2, 200
@@ -165,7 +171,9 @@ def get_rotation():
         global down
         global cx, cy, cz
         global accel_div, max_accel, accel_x, accel_y,  accel_delay, speed
-        global trip_switchx , trip_switchy , trip_value,  unit_speed
+        global calc_accel_x,  calc_accel_y,  unit_speed,  accel_tipping_point
+        
+        new_control = 1
         
         old_ax=ax
         old_ay=ay
@@ -182,8 +190,9 @@ def get_rotation():
         ax = coords[0]
         ay = coords[1]
         az = coords[2]
-        #print "x" + str(ax) + "y" + str(ay) + "z" + str(az)
-
+        #print "ax" + str(ax) + "ay" + str(ay) + "az" + str(az)
+        #print "cx" + str(cx) + "cy" + str(cy) + "cz" + str(cz)
+        
         #Calculate if we are moving from calibrated y coordinate
         if ax > cx+smooth:
             left = 1
@@ -197,43 +206,87 @@ def get_rotation():
             new_accel_x = int((cx-ax) / accel_div)
         else:
             new_accel_x = accel_x
-
+        
+        if new_control == 0:
+            #Old controls with acceleration increasing in steps instead of in direct proportion to the accelerometer
+            if new_accel_x > accel_x:
+                    accel_x = accel_x + unit_speed
+            elif new_accel_x < accel_x:
+                    accel_x = accel_x - unit_speed                
+            #Make sure we can't fly off too fast
+            if accel_x > max_accel:
+                accel_x = max_accel
+            if accel_x < 0:
+                accel_x = 0
+        else:
+            #Accelerate in direct proportion to accelerometer
+            #if right == 1:
+            accel_x = new_accel_x
+                    #calc_accel_y = new_accel_y
+                    #print "new plus speed: " + str(accel_y) + " Calc:" + str(calc_accel_y)
+            #else:
+            #elif new_accel_y < (calc_accel_y ):
+                    #Accel is an absolute number
+                    #accel_y = new_accel_y  #accel_y - unit_speed
+                    #calc_accel_y = new_accel_y
+                    #print "new negative speed: " + str(accel_y) + " Calc:" + str(calc_accel_y)
+                    
+            #Make sure we can't fly off too fast
+            if accel_x > max_accel:
+                accel_x = max_accel
+                #print "accely at max: " + str(max_accel)
+            if accel_x < 0:
+                accel_x = 0
+                #print "Stopped"
+        
             
-        if new_accel_x > accel_x:
-                accel_x = accel_x + unit_speed
-        elif new_accel_x < accel_x:
-                accel_x = accel_x - unit_speed                
-        if accel_x > max_accel:
-            accel_x = max_accel
-
-            
-        #Calculate if we are moving from calibrated y coordinate
-        if ay < cy+smooth:
+        #Calculate if we are moving from calibrated y coordinate. Cx /Cy simply gives a buffer around the dead center to avoid noise
+        #print "Detemine calibrated.."
+        if ay < cy-smooth:
+            #print "down"
             up = 0
             down = 1
-            new_accel_y = int((cy-ay) / (accel_div/2))
-        elif ay > cy-smooth:
+            #Accel_y is calculated as the diff between the calibrated center and now divided by a number of segments
+            #for Y accel_div is divided by 2 since there is less pixels - but! there is still 1000 points
+            new_accel_y = int((cy-ay) / (accel_div))
+            #print "down: " + str(new_accel_y) + " Calc:" + str(calc_accel_y)
+        elif ay > cy+smooth:
+            #print "up"
             up = 1
             down = 0
-            new_accel_y = int((ay-cy) / (accel_div/2))
+            new_accel_y = int((ay-cy) / (accel_div))
+            #print "up: " + str(new_accel_y) + " Calc:" + str(calc_accel_y)
         else:
             new_accel_y = accel_y
+            #print "Same "
 
-            
-        if new_accel_y > accel_y:
-                accel_y = accel_y + unit_speed         
-        elif new_accel_y < accel_y:
-                accel_y = accel_y - unit_speed
+        #Check to see if we are moving
+        #if new_accel_y > (calc_accel_y):
+        #if up == 1:
+                #If the new accel_y is greater (i.e. has move on a whole accel_div of points) then increase acceleration
+        accel_y = new_accel_y #accel_y + unit_speed
+                #calc_accel_y = new_accel_y
+                #print "new plus speed: " + str(accel_y) + " Calc:" + str(calc_accel_y)
+        #else:
+        #elif new_accel_y < (calc_accel_y ):
+                #Accel is an absolute number
+                #accel_y = new_accel_y  #accel_y - unit_speed
+                #calc_accel_y = new_accel_y
+                #print "new negative speed: " + str(accel_y) + " Calc:" + str(calc_accel_y)
+                
+        #Make sure we can't fly off too fast
         if accel_y > max_accel:
             accel_y = max_accel
-
-        coords = str(coords)
-        jaccel = str(coords) 
+            #print "accely at max: " + str(max_accel)
+        if accel_y < 0:
+            accel_y = 0
+            #print "Stopped"
         
+        coords = str(coords)
 
-
-        return (jaccel)
+        return (coords)
     except:
+        print str(sys.exc_info())
         return ('0,0,0,ERROR' + str(sys.exc_info()[:2]))
 
 def vibes():
@@ -811,7 +864,7 @@ def eat_or_die():
     global bumper_size ,  death_detail, snapy_size,  snapy_char,  map_accel, immortal, immortal_period,  bg_channel
     global toy_char,  toy_size,  toy_x,  toy_y,  toys,  blank_snapy,  score,  high_score,  snapy_length,  time_score
     global high_score3,  level_score,  level_speed, unit_speed, max_accel,  toy_slow_rate, background,  white
-    global food_rect,  toy_rect,  background,  snapy,  circ_rect,  food
+    global food_rect,  toy_rect,  background,  snapy,  circ_rect,  food,  cx,  cy
     
     count = y + 31
     happy_meal = 0
@@ -852,8 +905,8 @@ def eat_or_die():
         accel_x = 0
         accel_y = 0
         max_accel = max_accel - 1
-        if max_accel < (2 +  int(food_no / 5)):
-            max_accel = (2 +  int(food_no / 5))
+        if max_accel < (5 +  int(food_no / 5)):
+            max_accel = (5 +  int(food_no / 5))
         
         toys = 0
         vibrate_small()
@@ -926,9 +979,9 @@ def eat_or_die():
             snapy_length = 0
             level_score = 0
             speed = .5
-            max_accel = unit_speed * 2
-            if max_accel < 2:
-                max_accel = 2
+            max_accel = 5
+            if max_accel < 5:
+                max_accel = 5
             accel_x = 0
             accel_y = 0
             level_speed = speed
@@ -1042,7 +1095,7 @@ def eat_or_die():
         if toys == 1:
             map_toy(toy_x, toy_y)
             toy_rect.left,  toy_rect.top = toy_x,  toy_y
-        map_me(x, y)
+        #map_me(x, y)
         circ_rect.left = food_rect.left -8          #Food is 32x , circle is 48x
         circ_rect.top = food_rect.top - 8
         immortal = immortal_period
@@ -1181,8 +1234,8 @@ while 1:
             if vibx == 0:
                 vibrate_small()
                 vibx = 1
-        elif x > 800-32:
-            x = 800-32
+        elif x > screen_x-snapy_size:
+            x = screen_x-snapy_size
             if vibx == 0:
                 vibrate_small()
                 vibx = 1
@@ -1243,7 +1296,8 @@ while 1:
         blit_list.append(toy_rect)
     
         if debug_xy == 1:
-            pygame.display.set_caption ("x:" + str(x) + " y:" + str(y) + " ax:" + str(accel_x) + " ay:" + str(accel_y)) 
+            #pygame.display.set_caption ("x:" + str(x) + "y:" + str(y) + " ax:" + str(accel_x) + "ay:" + str(accel_y) + " X:" + str(ax) + "Y:" + str(ay))
+           pygame.display.set_caption ("x:" + '%03d' % x + "y:" + '%03d' % y  + " X:" '%03d' % ax + "Y:" + '%03d' % ay + " ax:" + str(accel_x) + "ay:" + str(accel_y) ) 
         else:
             score = time_score + level_score
             dis_hi = high_score
